.. :changelog:

History
-------

0.2.3 (2014-02-10)
++++++++++++++++++
* Fixed tests order (alphabetical)

0.2.2 (2014-02-10)
++++++++++++++++++
* Fixed variable substiution for multi varaibles
* Added variable substitution in 'url'

0.2.1 (2014-02-07)
++++++++++++++++++

* Fixed variables substitution if variable is None

0.2.0 (2014-02-07)
++++++++++++++++++

* Added support for form_params and headers

0.1.0 (2014-02-01)
++++++++++++++++++

* First release on PyPI.
